@@ -1,6 +1,6 @@
 /* fini.c
    Copyright (C) 1995 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -228,7 +228,7 @@ static char *spaces[]
 void testname (bool nested, int indent, name first, name last);
 void testnames (bool nested, int indent, int len, name first, name last);
 
-void
+int
 main (int argc, char **argv)
 {
   char buf[MAXNAMELEN];
