@@ -1,6 +1,6 @@
 /* intdoc.c
    Copyright (C) 1997 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -67,7 +67,7 @@ static char *elaborate_if_real (ffeintrinImp imp, int argno);
 static void print_type_string (char *c);
 
 int
-main (int argc, char **argv __attribute__ ((unused)))
+main (int argc, char **argv)
 {
   if (argc != 1)
     {
@@ -844,7 +844,7 @@ types of all the arguments.\n\n");
 	      break;
 
 	    default:
-	      assert ("E1" == NULL);
+	      assert ("N1" == NULL);
 	      break;
 	    }
 	  break;
