@@ -1,6 +1,6 @@
 /* lang-specs.h file for Fortran
-   Copyright (C) 1995, 1996 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Copyright (C) 1995-1997 Free Software Foundation, Inc.
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -27,12 +27,6 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 #ifdef __STDC__	/* Else stringizing of OO below won't work, but in
 		   K&R case we're not building the f77 language. */
 
-#ifdef OBJECT_SUFFIX	/* Not defined compiling gcc.c prior to 2.7.0. */
-#define OO "%O"
-#else
-#define OO ".o"
-#endif
-
   {".F", "@f77-cpp-input"},
   {".fpp", "@f77-cpp-input"},
   {"@f77-cpp-input",
@@ -52,7 +46,7 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 	%c %{O*:%{!O0:-D__OPTIMIZE__}} -traditional\
 	%{g*} %{W*} %{w} %{pedantic*} %{H} %{d*} %C %{D*} %{U*} %{i*} %Z\
 	%i %{!M:%{!MM:%{!E:%{!pipe:%g.i}}}}%{E:%W{o*}}%{M:%W{o*}}%{MM:%W{o*}} |\n",
-   "%{!M:%{!MM:%{!E:f771 %{!pipe:%g.i} -fset-g77-defaults \
+   "%{!M:%{!MM:%{!E:f771 %{!pipe:%g.i} -fset-g77-defaults %(f771) \
 		   %{!Q:-quiet} -dumpbase %b.F %{d*} %{m*} %{a}\
 		   %{g*} %{O*} %{W*} %{w} %{pedantic*} \
 		   %{v:-version -fversion} %{pg:-p} %{p} %{f*} %{I*}\
@@ -60,12 +54,27 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 		   %{pg:%{fomit-frame-pointer:%e-pg and -fomit-frame-pointer are incompatible}}\
 		   %{S:%W{o*}%{!o*:-o %b.s}}%{!S:-o %{|!pipe:%g.s}} |\n\
 	      %{!S:as %a %Y\
-		      %{c:%W{o*}%{!o*:-o %w%b" OO "}}%{!c:-o %d%w%u" OO "}\
+		      %{c:%W{o*}%{!o*:-o %w%b%O}}%{!c:-o %d%w%u%O}\
 		      %{!pipe:%g.s} %A\n }}}}"},
+  {".r", "@ratfor"},
+  {"@ratfor",
+   "ratfor %{C} %{v}\
+           %{C:%{!E:%eGNU C does not support -C without using -E}}\
+           %{!E:%{!pipe:-o %g.f}}%{E:%W{o*}} %i |\n",
+   "%{!E:f771 %{!pipe:%g.f} -fset-g77-defaults %(f771) \
+	   %{!Q:-quiet} -dumpbase %b.r %{d*} %{m*} %{a}\
+	   %{g*} %{O*} %{W*} %{w} %{pedantic*} \
+	   %{v:-version -fversion} %{pg:-p} %{p} %{f*} %{I*}\
+	   %{aux-info*}\
+	   %{pg:%{fomit-frame-pointer:%e-pg and -fomit-frame-pointer are incompatible}}\
+	   %{S:%W{o*}%{!o*:-o %b.s}}%{!S:-o %{|!pipe:%g.s}} |\n\
+	   %{!S:as %a %Y\
+	   %{c:%W{o*}%{!o*:-o %w%b%O}}%{!c:-o %d%w%u%O}\
+           %{!pipe:%g.s} %A\n }}"},
   {".f", "@f77"},
   {".for", "@f77"},
   {"@f77",
-   "%{!M:%{!MM:%{!E:f771 %i -fset-g77-defaults \
+   "%{!M:%{!MM:%{!E:f771 %i -fset-g77-defaults %(f771) \
 		   %{!Q:-quiet} -dumpbase %b.f %{d*} %{m*} %{a}\
 		   %{g*} %{O*} %{W*} %{w} %{pedantic*}\
 		   %{v:-version -fversion} %{pg:-p} %{p} %{f*} %{I*}\
@@ -73,8 +82,31 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 		   %{pg:%{fomit-frame-pointer:%e-pg and -fomit-frame-pointer are incompatible}}\
 		   %{S:%W{o*}%{!o*:-o %b.s}}%{!S:-o %{|!pipe:%g.s}} |\n\
 	      %{!S:as %a %Y\
-		      %{c:%W{o*}%{!o*:-o %w%b" OO "}}%{!c:-o %d%w%u" OO "}\
+		      %{c:%W{o*}%{!o*:-o %w%b%O}}%{!c:-o %d%w%u%O}\
 		      %{!pipe:%g.s} %A\n }}}}"},
+  {"@f77-version",
+   "cpp -lang-c %{nostdinc*} %{C} %{v} %{A*} %{I*} %{P} %I \
+      %{C:%{!E:%eGNU C does not support -C without using -E}} \
+      %{M} %{MM} %{MD:-MD %b.d} %{MMD:-MMD %b.d} %{MG} \
+      -undef -D__GNUC__=%v1 -D__GNUC_MINOR__=%v2 \
+      %{ansi:-trigraphs -$ -D__STRICT_ANSI__} \
+      %{!undef:%P} -D_LANGUAGE_FORTRAN %{trigraphs} \
+      %c %{O*:%{!O0:-D__OPTIMIZE__}} -traditional \
+      %{g*} %{W*} %{w} %{pedantic*} %{H} %{d*} %C %{D*} %{U*} %{i*} %Z \
+      /dev/null /dev/null \n\
+    f771 -fnull-version %(f771) \
+      %{!Q:-quiet} -dumpbase g77-version.f %{d*} %{m*} %{a} \
+      %{g*} %{O*} %{W*} %{w} %{pedantic*} \
+      -version -fversion %{f*} %{I*} -o %g.s /dev/null \n\
+    as %a %Y -o %g%O %g.s %A \n\
+    ld %l %X -o %g %g%O %{A} %{d} %{e*} %{m} %{N} %{n} \
+      %{r} %{s} %{t} %{u*} %{x} %{z} %{Z} \
+      %{!A:%{!nostdlib:%{!nostartfiles:%S}}} \
+      %{static:} %{L*} %D -lg2c -lm \
+      %{!nostdlib:%{!nodefaultlibs:%G %L %G}} \
+      %{!A:%{!nostdlib:%{!nostartfiles:%E}}} \
+      %{T*} \n\
+    %g \n"},
 
 #undef OO
 
