@@ -1,6 +1,6 @@
 /* lex.h -- Public #include File (module.h template V1.0)
    Copyright (C) 1995 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -16,7 +16,8 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Fortran; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.
 
    Owning Modules:
       lex.c
@@ -43,6 +44,7 @@ typedef enum
     FFELEX_typeRAW,
     FFELEX_typeQUOTE,
     FFELEX_typeDOLLAR,
+    FFELEX_typeHASH,
     FFELEX_typePERCENT,
     FFELEX_typeAMPERSAND,
     FFELEX_typeAPOSTROPHE,
@@ -116,9 +118,11 @@ struct _lextoken_
 
 /* Declare functions with prototypes. */
 
+void ffelex_display_token (ffelexToken t);
 bool ffelex_expecting_character (void);
 ffelexHandler ffelex_file_fixed (ffewhereFile wf, FILE *f);
 ffelexHandler ffelex_file_free (ffewhereFile wf, FILE *f);
+void ffelex_hash_kludge (FILE *f);
 void ffelex_init_1 (void);
 bool ffelex_is_names_expected (void);
 char *ffelex_line (void);
