@@ -1,6 +1,6 @@
 /* proj.h file for Gnu Fortran
    Copyright (C) 1995, 1996 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -36,40 +36,50 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 #endif
 #endif	/* !defined (BUILT_WITH_270) */
 
-/* This file used to attempt to allow for all sorts of broken systems.
-   Because the auto-configuration scripts in conf-proj(.in) didn't work
-   on all systems, and I received far too many bug reports about them,
-   I decided to stop trying to cater to broken systems at all, and
-   simply remove all but the simplest and most useful code (which is
-   still in proj.c).
-
-   So, if you find your system can't link because bsearch() or strtoul()
-   aren't found, please just fix your system, or hand-edit the code
-   below as appropriate.  I DO NOT WANT ANY "BUG REPORTS" ABOUT THIS.
-   g77 requires a working ANSI C environment, and if bsearch() and strtoul()
-   do not exist, or if <assert.h> isn't found, etc., then you don't have
-   one, and it is not g77's fault.  If it turns out g77 is simply
-   referring to the wrong system header file -- something I can verify
-   myself using my copy of the ANSI C standard -- I would like to know
-   about that.  Otherwise, g77 is not the place to fix problems with your
-   ANSI C implementation, though perhaps gcc might be.
-   --  burley@gnu.ai.mit.edu 1995-03-24  */
-
-#ifndef FFEPROJ_BSEARCH
-#define FFEPROJ_BSEARCH 1	/* 0=>use slow code in proj.c. */
-#endif
-#ifndef FFEPROJ_STRTOUL
-#define FFEPROJ_STRTOUL 1	/* 0=>use untested code in proj.c. */
-#endif
-
 /* Include files everyone gets. */
 
 #include "config.j"		/* Must come before any other #includes in gcc. */
 #include "assert.j"		/* Use gcc's assert.h. */
+#include <ctype.h>
 #include <stdio.h>
+
+#if HAVE_STDDEF_H
 #include <stddef.h>
+#endif
+
 #include <stdlib.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#if HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
+
+#if NEED_DECLARATION_MALLOC
+extern void *malloc (size_t);
+#endif
+
+#if NEED_DECLARATION_REALLOC
+extern void *realloc (void *, size_t);
+#endif
+
+#if NEED_DECLARATION_CALLOC
+extern void *calloc (size_t, size_t);
+#endif
+
+#if NEED_DECLARATION_INDEX
+extern char *index (char *, int);
+#endif
+
+#if NEED_DECLARATION_RINDEX
+extern char *rindex (char *, int);
+#endif
+
+#if NEED_DECLARATION_GETENV
+extern char *getenv (char *);
+#endif
 
 /* Generally useful definitions. */
 
