@@ -14,17 +14,16 @@ z_getc(Void)
 		}
 	return '\n';
 }
+
+ void
 #ifdef KR_headers
 z_putc(c)
 #else
 z_putc(int c)
 #endif
 {
-	if(f__icptr >= f__icend) err(f__svic->icierr,110,"inwrite");
-	if(f__recpos++ < f__svic->icirlen)
+	if (f__icptr < f__icend && f__recpos++ < f__svic->icirlen)
 		*f__icptr++ = c;
-	else	err(f__svic->icierr,110,"recend");
-	return 0;
 }
 z_rnew(Void)
 {
@@ -48,6 +47,9 @@ c_si(a) icilist *a;
 c_si(icilist *a)
 #endif
 {
+	if (f__init & 2)
+		f__fatal (131, "I/O recursion");
+	f__init |= 2;
 	f__elist = (cilist *)a;
 	f__fmtbuf=a->icifmt;
 	if(pars_f(f__fmtbuf)<0)
@@ -125,6 +127,7 @@ integer s_wsfi(icilist *a)
 }
 integer e_rsfi(Void)
 {	int n;
+	f__init &= ~2;
 	n = en_fio();
 	f__fmtbuf = NULL;
 	return(n);
@@ -132,11 +135,20 @@ integer e_rsfi(Void)
 integer e_wsfi(Void)
 {
 	int n;
+	f__init &= ~2;
 	n = en_fio();
 	f__fmtbuf = NULL;
-	if(f__icnum >= f__svic->icirnum)
-		return(n);
+	if(f__svic->icirnum != 1
+	 && (f__icnum >  f__svic->icirnum
+	 || (f__icnum == f__svic->icirnum && (f__recpos | f__hiwater))))
+		err(f__svic->icierr,110,"inwrite");
+	if (f__recpos < f__hiwater)
+		f__recpos = f__hiwater;
+	if (f__recpos >= f__svic->icirlen)
+		err(f__svic->icierr,110,"recend");
+	if (!f__recpos && f__icnum)
+		return n;
 	while(f__recpos++ < f__svic->icirlen)
 		*f__icptr++ = ' ';
-	return(n);
+	return n;
 }
