@@ -1,6 +1,6 @@
 /* sta.c -- Implementation File (module.c template V1.0)
    Copyright (C) 1995-1997 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -644,6 +644,7 @@ ffesta_second_ (ffelexToken t)
       break;
 
     case FFESTR_firstCASE:
+    case FFESTR_firstCASEDEFAULT:
       ffesta_add_possible_exec_ ((ffelexHandler) ffestb_R810);
       break;
 
