@@ -1,6 +1,6 @@
 /* stb.h -- Private #include File (module.h template V1.0)
-   Copyright (C) 1995 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Copyright (C) 1995, 1996 Free Software Foundation, Inc.
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -16,7 +16,8 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Fortran; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.
 
    Owning Modules:
       stb.c
@@ -131,7 +132,6 @@ extern struct _ffestb_args_ ffestb_args;
 
 /* Declare functions with prototypes. */
 
-ffelexHandler ffestb_unimplemented (ffelexToken t);
 ffelexHandler ffestb_beru (ffelexToken t);
 ffelexHandler ffestb_block (ffelexToken t);
 ffelexHandler ffestb_blockdata (ffelexToken t);
