@@ -1,6 +1,6 @@
 /* stt.h -- Private #include File (module.h template V1.0)
    Copyright (C) 1995 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -169,11 +169,12 @@ void ffestt_caselist_kill (ffesttCaseList list);
 void ffestt_dimlist_append (ffesttDimList list, ffebld lower, ffebld upper,
 			    ffelexToken t);
 ffebld ffestt_dimlist_as_expr (ffesttDimList list, ffeinfoRank *rank,
-			       ffebld *array_size, ffebld *extents);
+			       ffebld *array_size, ffebld *extents,
+			       bool is_ugly_assumed);
 ffesttDimList ffestt_dimlist_create (void);
 void ffestt_dimlist_dump (ffesttDimList list);
 void ffestt_dimlist_kill (ffesttDimList list);
-ffestpDimtype ffestt_dimlist_type (ffesttDimList dims);
+ffestpDimtype ffestt_dimlist_type (ffesttDimList dims, bool is_ugly_assumed);
 void ffestt_exprlist_append (ffesttExprList list, ffebld expr, ffelexToken t);
 ffesttExprList ffestt_exprlist_create (void);
 void ffestt_exprlist_drive (ffesttExprList list, void (*fn) ());
