@@ -1,6 +1,6 @@
 /* stu.c -- Implementation File (module.c template V1.0)
    Copyright (C) 1995-1997 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -924,7 +924,7 @@ ffestu_sym_exec_transition (ffesymbol s)
 static void
 ffestu_list_exec_transition_ (ffebld list)
 {
-  static in_progress = FALSE;
+  static bool in_progress = FALSE;
   ffebld item;
   ffesymbol symbol;
 
@@ -1116,7 +1116,7 @@ tail:				/* :::::::::::::::::::: */
 static bool
 ffestu_dummies_transition_ (ffesymbol (*symfunc) (), ffebld list)
 {
-  static in_progress = FALSE;
+  static bool in_progress = FALSE;
   ffebld item;
   ffesymbol symbol;
   bool uncertain = FALSE;
