@@ -1,6 +1,6 @@
 /* target.h -- Public #include File (module.h template V1.0)
    Copyright (C) 1995, 1996 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -1860,6 +1860,19 @@ void *ffetarget_memcpy_ (void *dst, void *src, size_t len);
 #define ffetarget_xor_logical3(res,l,r) (*(res) = (l) != (r), FFEBAD)
 #define ffetarget_xor_logical4(res,l,r) (*(res) = (l) != (r), FFEBAD)
 
+/* Begin the cruft g77 used to patch into gcc-2.7/real.h.  */
+
+extern REAL_VALUE_TYPE ereal_unto_float PROTO((long));
+extern REAL_VALUE_TYPE ereal_unto_double PROTO((long *));
+
+/* Inverse of REAL_VALUE_TO_TARGET_DOUBLE. */
+#define REAL_VALUE_UNTO_TARGET_DOUBLE(d)  (ereal_unto_double (d))
+
+/* Inverse of REAL_VALUE_TO_TARGET_SINGLE. */
+#define REAL_VALUE_UNTO_TARGET_SINGLE(f)  (ereal_unto_float (f))
+
+/* End the cruft g77 used to patch into gcc-2.7/real.h.  */
+
 /* End of #include file. */
 
 #endif
