@@ -1,6 +1,6 @@
 /* top.c -- Implementation File (module.c template V1.0)
    Copyright (C) 1995-1997 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -80,6 +80,7 @@ bool ffe_is_ident_ = TRUE;
 bool ffe_is_init_local_zero_ = FFETARGET_defaultIS_INIT_LOCAL_ZERO;
 bool ffe_is_mainprog_;		/* TRUE if current prog unit known to be
 				   main. */
+bool ffe_is_null_version_ = FALSE;
 bool ffe_is_onetrip_ = FALSE;
 bool ffe_is_silent_ = TRUE;
 bool ffe_is_typeless_boz_ = FALSE;
@@ -169,12 +170,11 @@ ffe_decode_option (char *opt)
       if (strcmp (&opt[2], "version") == 0)
 	ffe_set_is_version (TRUE);
       else if (strcmp (&opt[2], "null-version") == 0)
-	;			/* Someday generate program to print version
-				   info.  */
+	ffe_set_is_null_version (TRUE);
       else if (strcmp (&opt[2], "set-g77-defaults") == 0)
 	{
 	  ffe_is_do_internal_checks_ = 0;
-#if BUILT_FOR_270	/* User must have applied patch (circa 2.7.2 and beyond). */
+#if BUILT_FOR_270 && !BUILT_FOR_280
 	  flag_move_all_movables = 1;
 	  flag_reduce_all_givs = 1;
 	  flag_rerun_loop_opt = 1;
