@@ -1,6 +1,6 @@
 /* where.c -- Implementation File (module.c template V1.0)
    Copyright (C) 1995 Free Software Foundation, Inc.
-   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).
+   Contributed by James Craig Burley (burley@gnu.org).
 
 This file is part of GNU Fortran.
 
@@ -270,7 +270,7 @@ ffewhere_line_new (ffewhereLineNumber ln)
 #endif
       wl = malloc_new_ks (ffe_pool_file (), "FFEWHERE line",
 			  offsetof (struct _ffewhere_line_, content)
-			  + ffelex_line_length () + 1);
+			  + (size_t) ffelex_line_length () + 1);
       wl->next = (ffewhereLine) &ffewhere_root_line_;
       wl->previous = ffewhere_root_line_.last;
       wl->previous->next = wl;
@@ -354,17 +354,11 @@ ffewhere_set_from_track (ffewhereLine *wol, ffewhereColumn *woc,
   ffewhereIndex j;
   ffewhereIndex k;
 
-  if (i == 0)
+  if ((i == 0) || (i >= FFEWHERE_indexMAX))
     {
       *wol = ffewhere_line_use (wrl);
       *woc = ffewhere_column_use (wrc);
     }
-  else if (i >= FFEWHERE_indexMAX)
-    {
-      assert ("i >= FFEWHERE_indexMAX" == NULL);
-      *wol = ffewhere_line_unknown ();
-      *woc = ffewhere_column_unknown ();
-    }
   else
     {
       ln = ffewhere_line_number (wrl);
